@@ -131,12 +131,18 @@ def random_int_str(range_from, range_to, zero_padding):
         return str(i)
 
 def is_empty(value):
-    if (isinstance(value, str)):
+    if isinstance(value, str):
         if value is None or value.strip()=='' or value.strip()=='null' or value.strip()=='None':
             return True
-        return False
+        
+    elif isinstance(value,(dict,list)):
+        if len(value)==0:
+            return True
+          
     else:
         return value is None
+    
+    return False
 
 def is_not_empty(value):
     return is_empty(value)==False
